@@ -76,20 +76,21 @@ macro_rules! trace_named_parameter_not_found {
 }
 
 pub mod engine {
+  use crate::feel::errors::*;
   use crate::feel::eval_bif;
-  use dmntk_feel::values::Values;
-  use {
-    crate::feel::errors::*,
-    dmntk_common::{null_with_trace, Result, Stringify},
-    dmntk_feel::{
-      bif::Bif,
-      context::FeelContext,
-      is_integer, round_half_to_even, subtract,
-      values::{FunctionBody, Value, VALUE_FALSE, VALUE_NULL, VALUE_NULL_WITH_TRACE, VALUE_TRUE},
-      AstNode, FeelDate, FeelDateTime, FeelDaysAndTimeDuration, FeelTime, FeelType, FeelYearsAndMonthsDuration, Name, OptAstNode, Scope,
-    },
-    std::{borrow::Borrow, collections::BTreeMap, collections::HashSet, convert::TryFrom, ops::Deref, str::FromStr},
+  use dmntk_common::{null_with_trace, Result, Stringify};
+  use dmntk_feel::bif::Bif;
+  use dmntk_feel::context::FeelContext;
+  use dmntk_feel::values::{FunctionBody, Value, Values, VALUE_FALSE, VALUE_NULL, VALUE_NULL_WITH_TRACE, VALUE_TRUE};
+  use dmntk_feel::{
+    is_integer, round_half_to_even, subtract, AstNode, FeelDate, FeelDateTime, FeelDaysAndTimeDuration, FeelTime, FeelType, FeelYearsAndMonthsDuration, Name,
+    OptAstNode, Scope,
   };
+  use std::borrow::Borrow;
+  use std::collections::{BTreeMap, HashSet};
+  use std::convert::TryFrom;
+  use std::ops::Deref;
+  use std::str::FromStr;
 
   /// Evaluates the AST for `FEEL` expression.
   pub fn eval(scope: &Scope, node: &AstNode) -> Result<Value> {
@@ -1855,7 +1856,7 @@ pub mod engine {
     argument_context: &mut FeelContext,
   ) {
     if argument_value.type_of().is_conformant(formal_parameter_type) {
-      if let Some(derived_value) = formal_parameter_type.derive(argument_value) {
+      if let Ok(derived_value) = formal_parameter_type.retrieve_value_with_type_checking(argument_value) {
         argument_context.set_entry(formal_parameter_name, derived_value);
       } else {
         //FIXME replace println with something else
