@@ -18,14 +18,10 @@
 
 /// Built-in functions with named parameters.
 pub mod named {
-  use {
-    crate::trace_named_parameter_not_found,
-    dmntk_common::Result,
-    dmntk_feel::{
-      values::{Value, VALUE_NULL, VALUE_NULL_WITH_TRACE},
-      Name,
-    },
-  };
+  use crate::trace_named_parameter_not_found;
+  use dmntk_common::Result;
+  use dmntk_feel::values::{Value, VALUE_NULL, VALUE_NULL_WITH_TRACE};
+  use dmntk_feel::Name;
 
   lazy_static! {
     static ref NAME_DATE: Name = Name::from("date");
@@ -516,9 +512,10 @@ pub mod named {
 /// Built-in functions with positional parameters.
 pub mod positional {
   use crate::feel::evaluate;
+  use crate::trace_invalid_number_of_parameters;
+  use dmntk_common::Result;
   use dmntk_feel::values::{Value, VALUE_NULL, VALUE_NULL_WITH_TRACE};
   use dmntk_feel::{AstNode, Scope};
-  use {crate::trace_invalid_number_of_parameters, dmntk_common::Result};
 
   pub fn abs(scope: &Scope, positional_parameters: &[AstNode]) -> Result<Value> {
     match positional_parameters.len() {
@@ -1267,8 +1264,7 @@ pub mod positional {
 /// Core built-in functions used by named and positional implementations.
 pub mod core {
   use crate::feel::evaluate_equals;
-  use crate::trace_invalid_value;
-  use crate::trace_invalid_value_type;
+  use crate::{trace_invalid_value, trace_invalid_value_type};
   use dmntk_common::Stringify;
   use dmntk_feel::values::Value::YearsAndMonthsDuration;
   use dmntk_feel::values::{Value, Values, VALUE_FALSE, VALUE_NULL, VALUE_NULL_WITH_TRACE, VALUE_TRUE};
