@@ -19,14 +19,14 @@ use super::*;
 #[test]
 fn test_positive_unary_tests() {
   let scope = &te_scope("{}");
-  valid_unary_tests(scope, "-");
-  valid_unary_tests(scope, "1");
-  valid_unary_tests(scope, "1,2");
-  valid_unary_tests(scope, "1,2,3");
-  valid_unary_tests(scope, "[]");
-  valid_unary_tests(scope, "[1]");
-  valid_unary_tests(scope, "[1,2]");
-  valid_unary_tests(scope, "[1,2,3]");
-  valid_unary_tests(scope, "[1..2]");
-  valid_unary_tests(scope, "not(1,2,3)");
+  valid_unary_tests(false, scope, "-");
+  valid_unary_tests(false, scope, "1");
+  valid_unary_tests(false, scope, "1,2");
+  valid_unary_tests(false, scope, "1,2,3");
+  valid_unary_tests(false, scope, "[]");
+  valid_unary_tests(false, scope, "[1]");
+  valid_unary_tests(false, scope, "[1,2]");
+  valid_unary_tests(false, scope, "[1,2,3]");
+  valid_unary_tests(false, scope, "[1..2]");
+  valid_unary_tests(false, scope, "not(1,2,3)");
 }
