@@ -15,15 +15,21 @@
  */
 
 extern crate dmntk_common;
+extern crate dmntk_examples;
 extern crate dmntk_feel;
 extern crate dmntk_feel_parser;
+extern crate dmntk_model;
+extern crate dmntk_recognizer;
 #[macro_use]
 extern crate lazy_static;
 extern crate regex;
 
-pub mod feel;
+mod feel;
 mod model;
 
-pub use crate::feel::evaluate;
-pub use crate::feel::evaluate_context;
-pub use crate::feel::evaluate_decision_table_test;
+pub use crate::feel::{evaluate, evaluate_context, evaluate_equals, evaluate_function, evaluate_max, evaluate_min, evaluate_node_type, evaluate_sum};
+pub use crate::model::enricher::enrich_model;
+pub use crate::model::eval_bkm::evaluate_business_knowledge_model_by_name;
+pub use crate::model::eval_dec::evaluate_decision_by_name;
+pub use crate::model::eval_dec_service::evaluate_decision_service_by_name;
+pub use crate::model::{evaluate_decision_table_and_context, evaluate_decision_table_and_test};
